# 人才标签 API 接口文档

本文档详细说明了人才标签管理的四个 API 接口，包括创建、查询、更新和删除人才标签的操作。

## 目录

- [创建人才标签](#创建人才标签)
- [获取人才标签列表](#获取人才标签列表)
- [更新人才标签](#更新人才标签)
- [删除人才标签](#删除人才标签)

## 创建人才标签

创建新的人才标签节点到 Neo4j 图数据库中。

### 请求信息

- **URL:** `/api/parse/create-talent-tag`
- **方法:** `POST`
- **Content-Type:** `application/json`

### 请求参数

| 参数名      | 类型   | 必填 | 描述                               |
|------------|--------|------|-----------------------------------|
| name       | String | 是   | 标签名称                           |
| category   | String | 否   | 标签分类，默认为"未分类"           |
| description| String | 否   | 标签描述                           |
| status     | String | 否   | 标签状态，默认为"active"           |

### 请求示例

```json
{
  "name": "Java开发",
  "category": "技术能力/人才",
  "description": "熟练掌握Java编程语言和相关框架",
  "status": "active"
}
```

### 响应参数

| 参数名      | 类型    | 描述                               |
|------------|---------|-----------------------------------|
| success    | Boolean | 操作是否成功                       |
| message    | String  | 操作结果描述                       |
| code       | Integer | 状态码                             |
| data       | Object  | 创建的标签信息                     |

### 响应示例 - 成功

```json
{
  "success": true,
  "message": "人才标签创建成功",
  "code": 200,
  "data": {
    "id": 12345,
    "name": "Java开发",
    "en_name": "Java Development",
    "category": "技术能力/人才",
    "description": "熟练掌握Java编程语言和相关框架",
    "status": "active",
    "time": "2023-07-20 14:30:45"
  }
}
```

### 响应示例 - 失败

```json
{
  "success": false,
  "message": "标签名称不能为空",
  "code": 400,
  "data": null
}
```

### 状态码

| 状态码 | 描述                 |
|--------|---------------------|
| 200    | 请求成功             |
| 400    | 请求参数错误         |
| 500    | 服务器内部错误       |

---

## 获取人才标签列表

从 Neo4j 图数据库获取人才标签列表，包括所有分类包含"talent"或"人才"的标签。

### 请求信息

- **URL:** `/api/parse/get-talent-tag-list`
- **方法:** `GET`

### 请求参数

无

### 响应参数

| 参数名      | 类型    | 描述                               |
|------------|---------|-----------------------------------|
| success    | Boolean | 操作是否成功                       |
| message    | String  | 操作结果描述                       |
| code       | Integer | 状态码                             |
| data       | Array   | 人才标签列表                       |

### 响应示例 - 成功

```json
{
  "success": true,
  "message": "获取人才标签列表成功",
  "code": 200,
  "data": [
    {
      "id": 12345,
      "name": "Java开发",
      "en_name": "Java Development",
      "category": "技术能力/人才",
      "description": "熟练掌握Java编程语言和相关框架",
      "status": "active",
      "time": "2023-07-20 14:30:45"
    },
    {
      "id": 12346,
      "name": "Python开发",
      "en_name": "Python Development",
      "category": "技术能力/人才",
      "description": "熟练掌握Python编程语言和相关框架",
      "status": "active",
      "time": "2023-07-19 10:15:22"
    }
  ]
}
```

### 响应示例 - 失败

```json
{
  "success": false,
  "message": "获取人才标签列表失败: 数据库连接错误",
  "code": 500,
  "data": []
}
```

### 状态码

| 状态码 | 描述                 |
|--------|---------------------|
| 200    | 请求成功             |
| 500    | 服务器内部错误       |

---

## 更新人才标签

更新已有的人才标签节点属性。

### 请求信息

- **URL:** `/api/parse/update-talent-tag/{tag_id}`
- **方法:** `PUT`
- **Content-Type:** `application/json`

### 路径参数

| 参数名 | 类型    | 描述           |
|--------|---------|---------------|
| tag_id | Integer | 要更新的标签ID |

### 请求参数

| 参数名      | 类型   | 必填 | 描述                               |
|------------|--------|------|-----------------------------------|
| name       | String | 否   | 标签名称                           |
| category   | String | 否   | 标签分类                           |
| description| String | 否   | 标签描述                           |
| status     | String | 否   | 标签状态                           |

注意：至少需要提供一个参数进行更新。

### 请求示例

```json
{
  "name": "高级Java开发",
  "description": "精通Java编程语言和相关框架，有丰富的项目经验"
}
```

### 响应参数

| 参数名      | 类型    | 描述                               |
|------------|---------|-----------------------------------|
| success    | Boolean | 操作是否成功                       |
| message    | String  | 操作结果描述                       |
| code       | Integer | 状态码                             |
| data       | Object  | 更新后的标签信息                   |

### 响应示例 - 成功

```json
{
  "success": true,
  "message": "人才标签更新成功",
  "code": 200,
  "data": {
    "id": 12345,
    "name": "高级Java开发",
    "en_name": "Senior Java Development",
    "category": "技术能力/人才",
    "description": "精通Java编程语言和相关框架，有丰富的项目经验",
    "status": "active",
    "time": "2023-07-21 09:45:30"
  }
}
```

### 响应示例 - 失败

```json
{
  "success": false,
  "message": "未找到ID为12345的标签",
  "code": 404,
  "data": null
}
```

### 状态码

| 状态码 | 描述                 |
|--------|---------------------|
| 200    | 请求成功             |
| 400    | 请求参数错误         |
| 404    | 标签不存在           |
| 500    | 服务器内部错误       |

---

## 删除人才标签

删除指定的人才标签节点及其关系。

### 请求信息

- **URL:** `/api/parse/delete-talent-tag/{tag_id}`
- **方法:** `DELETE`

### 路径参数

| 参数名 | 类型    | 描述           |
|--------|---------|---------------|
| tag_id | Integer | 要删除的标签ID |

### 请求参数

无

### 响应参数

| 参数名      | 类型    | 描述                               |
|------------|---------|-----------------------------------|
| success    | Boolean | 操作是否成功                       |
| message    | String  | 操作结果描述                       |
| code       | Integer | 状态码                             |
| data       | Object  | 被删除的标签信息                   |

### 响应示例 - 成功

```json
{
  "success": true,
  "message": "人才标签删除成功",
  "code": 200,
  "data": {
    "id": 12345,
    "name": "高级Java开发",
    "en_name": "Senior Java Development",
    "category": "技术能力/人才",
    "description": "精通Java编程语言和相关框架，有丰富的项目经验",
    "status": "active",
    "time": "2023-07-21 09:45:30"
  }
}
```

### 响应示例 - 失败

```json
{
  "success": false,
  "message": "未找到ID为12345的标签",
  "code": 404,
  "data": null
}
```

### 状态码

| 状态码 | 描述                 |
|--------|---------------------|
| 200    | 请求成功             |
| 404    | 标签不存在           |
| 500    | 服务器内部错误       |

---

## 开发注意事项

1. 所有请求和响应的 Content-Type 均为 `application/json`。
2. 创建标签时，name 字段为必填，其他字段可选。
3. 更新标签时，至少需要提供一个要更新的属性。
4. 删除标签时会同时删除该标签与其他节点之间的所有关系。
5. 英文名称（en_name）会根据中文名称自动生成，无需手动提供。 